/*****************************************************************************
   Copyright (C) 2006 NTT
  *****************************************************************************/
/** 
 * @file    SyncXLOG.h
 * @brief   XLOG同期処理に関する定数の定義
 *
 * XLOG同期処理に使用するテーブル及び定数を定義する。
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#ifndef SYNCXLOG_H_
#define SYNCXLOG_H_

/*****************
 * 定数定義
 ****************/
/**
 * @def     CC_CMDFMT_SYNCXLOG
 * @brief   XLOG同期コマンド生成用フォーマット
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define CC_CMDFMT_SYNCXLOG	"rsync -e ssh -aqI --delete %s@%s:%s/ %s"

/**
 * @def     CC_COMMANDMAX_SYNCXLOG
 * @brief   コマンド最大長
 *
 * @attention 32という値は、コマンド生成用フォーマット内の可変部(%s)以外の文字列の長さを表す。
 *            コマンドを修正する場合は、値に注意すること。
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define CC_COMMANDMAX_SYNCXLOG	PREX_MAX_USERNAME_LEN + PREX_MAX_HOSTNAME_LEN + PREX_MAX_PATH_LEN + PREX_MAX_PATH_LEN + 32

/**
 * @def     ARGINDEX_HOST
 * @brief   ホスト名を示すargv[]のインデックス
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ARGINDEX_HOST	1

/**
 * @def     ARGINDEX_PORT
 * @brief   ポート番号を示すargv[]のインデックス
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ARGINDEX_PORT	2

/**
 * @def     ARGINDEX_POLLING_INTERVAL
 * @brief   ポート番号を示すargv[]のインデックス
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ARGINDEX_POLLING_INTERVAL	3

/**
 * @def     ARGINDEX_WALHOST
 * @brief   WALディレクトリを持つリモートホストを示すargv[]のインデックス
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ARGINDEX_WALHOST	4

/**
 * @def     ARGINDEX_WALUSER
 * @brief   WALディレクトリを持つリモートホストへのログインユーザ名を示すargv[]のインデックス
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ARGINDEX_WALUSER	5

/**
 * @def     ARGINDEX_REMOTEWALDIR
 * @brief   リモート側WALディレクトリを示すargv[]のインデックス
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ARGINDEX_REMOTEWALDIR	6

/**
 * @def     ARGINDEX_LOCALWALDIR
 * @brief   ローカル側WALディレクトリを示すargv[]のインデックス
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ARGINDEX_LOCALWALDIR	7

/**
 * @def     ARGINDEX_ARCHIVEHOST
 * @brief   アーカイブログディレクトリを持つリモートホストを示すargv[]のインデックス
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ARGINDEX_ARCHIVEHOST	8

/**
 * @def     ARGINDEX_WALUSER
 * @brief   アーカイブログディレクトリを持つリモートホストへのログインユーザ名を示すargv[]のインデックス
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ARGINDEX_ARCHIVEUSER	9

/**
 * @def     ARGINDEX_REMOTEWALDIR
 * @brief   リモート側アーカイブログディレクトリを示すargv[]のインデックス
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ARGINDEX_REMOTEARCHIVEDIR	10

/**
 * @def     ARGINDEX_LOCALWALDIR
 * @brief   ローカル側アーカイブログディレクトリを示すargv[]のインデックス
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ARGINDEX_LOCALARCHIVEDIR	11

/*******************
 * プロトタイプ宣言
 ******************/
int SyncXLOG(char* remotewalhost, char* remotewaluser, char* remotewaldir, char* localwaldir, 
             char* remotearchivehost, char* remotearchiveuser, char* remotearchivedir, char* localarchivedir);

#endif /* SYNCXLOG_H_ */
