#!/bin/sh
#####################################################################
# Copyright   : Copyright (C) 2006 NTT
#/**
# * @file    getmsgkey.sh
# * @brief   メッセージキューキー値取得処理
# *
# * 設定ファイル（WALWriter.conf）からメッセージキューのキー値（prex_msgkey）を取得する。
# *
# *   詳細は以下のとおり。
# *     -# 設定ファイル（WALWriter.conf）の存在確認を行う（test -r ${HOME}/prex/WALWriter.conf）。
# *        設定ファイルが存在しない、または読み取り不可である場合、エラーとして、
# *        syslogにメッセージを出力後（prexsyslogコマンド）、戻り値としてRET_NGを返却して終了する。
# *     -# 設定ファイル（WALWriter.conf）からメッセージキューのキー値が設定されている（先頭が「prex_msgkey 」と記述されている）行を検索する（grep ^prex_msgkey -f[ファイルパス] | tail -n 1）。
# *        grepコマンドのエラーの場合、syslogにメッセージを出力後（prexsyslogコマンド）、戻り値としてRET_NGを返却して終了する。
# *     -# 行が見つからない場合、キー値はデフォルト値"7890"を使用する。
# *     -# 行が見つかった場合、検索結果における最後の行から設定されているキー値を取得する(awk -F'=' '{print $2}')。
# *     -# キー値が取得できない場合、エラーとして、syslogにメッセージを出力後（prexsyslogコマンド）、戻り値としてRET_NGを返却して終了する。
# *     -# キー値が取得できた場合、値が正数値かチェックを行う(expr [キー値] + 1 → test $? -lt 2 →test 0 -el [キー値])。exprコマンドのエラーの場合、syslogにメッセージを出力後（prexsyslogコマンド）、戻り値としてRET_NGを返却して終了する。
# *        正数値でない場合、エラーとして、syslogにメッセージを出力後（prexsyslogコマンド）、戻り値としてRET_NGを返却して終了する。
# *     -# キー値を標準出力に出力し（echoコマンド）、戻り値としてRET_OKを返却して終了する。
# *
# * @pre       WALWriter.confは、規定されたディレクトリ（${HOME}/prex）配下に格納されていること。
# * @retval    RET_OK(0)     取得正常
# * @retval    RET_NG(1)     取得異常
# *
# * @version 1.0.0
# * @date    09/01/2006
# * @since   1.0
# */

export PREX_HOME=${HOME}

# DEFINE値取り込み
. ${PREX_HOME}/prex/bin/prexdefine.sh

# WALWriter.confが存在しない、まはた読み込み不可の場合
if [ ! -r ${wwconffile} ]; then
	${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_FAILEDTOOPENFILE} ${0} ${LINENO} ${MSGWD_WWCONFIGFILE}
	exit ${RET_NG}
fi

# WALWriter.confからmsgkey値を取得
gettmp=`grep ^${ENVITEM_MSGKEY} ${wwconffile}`
getret=${?}
if [ ${getret} -eq ${RET_OK} ]; then
	retmsgkey=`grep ^${ENVITEM_MSGKEY} ${wwconffile} | tail -n 1 | awk -F '=' '{print $2}'`
elif [ ${getret} -eq ${RET_GREP_NOTFOUND} ]; then
	# 見つからない場合デフォルトキー(7890)
	echo ${defalutkey}
	exit ${RET_OK}
else
	${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_ERRORGREP} ${0} ${LINENO}
	exit ${RET_NG}
fi

# 取得できていない場合エラー
if [ -z ${retmsgkey} ]; then
	${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_ILLEGALPARAM} ${0} ${LINENO} ${MSGWD_ENVITEM_MSGKEY}
	exit ${RET_NG}
fi

# msgkeyが正の整数値かを判定
expr ${retmsgkey} + 1 > /dev/null 2>&1
if [ ${?} -lt 2 ]; then
	if [ ${retmsgkey} -gt 0 ]; then
		# 数値でかつ正数値の場合
		echo ${retmsgkey}
		exit ${RET_OK}
	else
		${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_ILLEGALPARAM} ${0} ${LINENO} ${MSGWD_ENVITEM_MSGKEY}
		exit ${RET_NG}
	fi		
else
	${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_ILLEGALPARAM} ${0} ${LINENO} ${MSGWD_ENVITEM_MSGKEY}
	exit ${RET_NG}
fi
