#!/bin/sh 
#####################################################################
# Copyright   : Copyright (C) 2006-2007 NTT
#/**
# * @file    tosby.sh
# * @brief   Clusterコマンド（SBY化要求）処理
# *
# * PREXをSBY状態に遷移させる。
# *
# *   詳細は以下のとおり。
# *     -# コマンドパラメータのチェックを行う。以下に示すパラメータ指定は、正常なパラメータとみなす。
# *        - 第1パラメータが指定されている、第2パラメータ以降は指定されていない。
# *        - 第1パラメータが指定されている、第2パラメータに-iが指定されている、第3パラメータ以降は指定されていない。
# *     -# 正常なパラメータとみなせない場合には、エラーとして、syslogにエラーメッセージを出力後（prexsyslogコマンド）、
# *        戻り値としてRET_NGを返却して終了する。
# *     -# メッセージキューを作成する（mkmsgqコマンド）。 
# *        エラーがあった場合、syslogにメッセージを出力後（prexsyslogコマンド）、戻り値としてRET_NGを返却して終了する。
# *     -# 初期起動オプションの指定がある場合は、以下の5～7の処理を行う。
# *     -# WALWriterプロセスをバックグラウンドで起動する（WALWriterコマンド）。起動する際、初期起動パラメータを指定する。
# *     -# WALWriterプロセスの起動確認を行う。プロセスが存在しない場合は、1秒毎に再確認を繰り返す。
# *        再確認を5回行ったにもかかわらずプロセスが存在しない場合、syslogにメッセージを出力後（prexsyslogコマンド）、戻り値としてRET_NGを返却して終了する。
# *        grepコマンドのエラーの場合、syslogにメッセージを出力後（prexsyslogコマンド）、戻り値としてRET_NGを返却して終了する。
# *     -# postmasterプロセスの起動を行う（pg_ctl start）。
# *     -# 初期起動オプションの指定がない場合は、以下の9～11の処理を行う。
# *     -# WALWriterプロセスをバックグラウンドで起動する（WALWriterコマンド）。起動する際、初期起動パラメータを指定しない。
# *     -# WALWriterプロセスの起動確認を行う。プロセスが存在しない場合は、1秒毎に再確認を繰り返す。
# *        再確認を5回行ったにもかかわらずプロセスが存在しない場合、syslogにメッセージを出力後（prexsyslogコマンド）、戻り値としてRET_NGを返却して終了する。
# *        grepコマンドのエラーの場合、syslogにメッセージを出力後（prexsyslogコマンド）、戻り値としてRET_NGを返却して終了する。
# *     -# 「SBY化応答」メッセージの受信を行う（msgsbyrecvコマンド）。
# *        エラーがあった場合、syslogにメッセージを出力後（prexsyslogコマンド）、戻り値としてRET_NGを返却して終了する。
# *     -# postmasterプロセスの起動確認を行う。プロセスが存在しない場合は、1秒毎に再確認を繰り返す。
# *        再確認を5回行ったにもかかわらずプロセスが存在しない場合、syslogにメッセージを出力後（prexsyslogコマンド）、戻り値としてRET_NGを返却して終了する。
# *        grepコマンドのエラーの場合、syslogにメッセージを出力後（prexsyslogコマンド）、戻り値としてRET_NGを返却して終了する。
# *     -# リカバリプロセスの生成(REDO処理の完了)を待機を行なう。1秒毎にリカバリプロセスの存在確認を繰り返す。
# *        この時、postmasterプロセスの存在確認を併せて行い、postmasterプロセスが存在しない場合、戻り値としてRET_NGを返却して終了する。
# *     -# 戻り値としてRET_OKを返却して終了する。
# *
# * @pre         本スクリプトは、Clusterコマンド(初期起動)からのみ呼び出される。
# * @note      「SBY化応答」メッセージは、WALWriterのバックアップ取得処理が完了したとき、
# *             またはWALWriterが異常終了したときに、WALWriterから送信される。
# *             本コマンドでは、WALWriterのバックアップ取得が完了するまで待ち合わせるために、
# *             メッセージの受信を待つ処理を行っている。
# * @param[in]   正数値        メッセージキューのキー値
# * @param[in]   -i            初期起動時オプション
# * @retval      RET_OK(0)     SBY化成功
# * @retval      RET_NG(1)     SBY化失敗
# *
# * @version 1.1.0
# * @date    09/14/2007
# * @since   1.0
# */

export PREX_HOME=${HOME}

RETRYCOUNTMAX=5

# DEFINE値取り込み
. ${PREX_HOME}/prex/bin/prexdefine.sh

# 引数チェック
if [ ${#} -eq 1 ] ; then
	# 何もしない
	:
elif [ ${#} -eq 2 ] ; then
	# 「-i」か確認
	if [ ${2} != ${PARAM_INIT} ] ; then
		${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_ILLEGALPARAM} ${0} ${LINENO} ${MSGWD_INIT_OPTION}
		exit ${RET_NG}
	fi 
else
	${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_ILLEGALPARAM} ${0} ${LINENO} ${MSGWD_NUMOFPARAM}
	exit ${RET_NG}
fi 

key=${1}

# メッセージキューの作成
${PREX_BIN}/mkmsgq ${key}
if [ ${?} -ne ${RET_OK} ] ; then
	${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_FAILEDTOCREATEMSGQ} ${0} ${LINENO}
	exit ${RET_NG}
fi 

if [ -n "${2}" ] ; then
	# 初期起動オプション指定時、WALWriter起動
	${PREX_BIN}/WALWriter -i &

	# WALWriterプロセスの起動確認
	RETRYCOUNT=0
	while :
	do
		tmp=`ps x | grep ${PNAME_WALWriter} | grep -v ${CMDNAME_GREP}`
		ret=${?}
		if [ ${ret} -eq ${RET_GREP_NOTFOUND} ] ; then
			if [ ${RETRYCOUNT} -lt ${RETRYCOUNTMAX} ]; then
                                #プロセスがまだ起動していなければ1秒後に再確認
                                RETRYCOUNT=`expr ${RETRYCOUNT} + 1`
                                sleep 1
                                continue
			else
                                # 5回リトライしても存在しない場合、エラー
                                ${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_FAILEDTOBOOTPROCESS} ${0} ${LINENO} ${MSGWD_WALWRITER}
                                exit ${RET_NG}
			fi
		elif [ ${ret} -ne ${RET_OK} ]; then
			# grepコマンドエラー
			${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_ERRORGREP} ${0} ${LINENO}
			exit ${RET_NG}
		else
			# 正常
			break
		fi 
	done

	# postmaster起動
	pg_ctl start
	
else
	# 初期起動オプション未指定、WALWriter起動
	${PREX_BIN}/WALWriter &

        # WALWriterプロセスの起動確認
        RETRYCOUNT=0
        while :
        do
                tmp=`ps x | grep ${PNAME_WALWriter} | grep -v ${CMDNAME_GREP}`
                ret=${?}
                if [ ${ret} -eq ${RET_GREP_NOTFOUND} ] ; then
                        if [ ${RETRYCOUNT} -lt ${RETRYCOUNTMAX} ]; then
                                #プロセスがまだ起動していなければ1秒後に再確認
                                RETRYCOUNT=`expr ${RETRYCOUNT} + 1`
                                sleep 1
                                continue
                        else
                                # 5回リトライしても存在しない場合、エラー
                                ${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_FAILEDTOBOOTPROCESS} ${0} ${LINENO} ${MSGWD_WALWRITER}
                                exit ${RET_NG}
                        fi
                elif [ ${ret} -ne ${RET_OK} ]; then
                        # grepコマンドエラー
                        ${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_ERRORGREP} ${0} ${LINENO}
                        exit ${RET_NG}
                else
                        # 正常
                        break
                fi
        done	

	# SBY化応答受信待ち
	${PREX_BIN}/msgsbyrecv ${key}
	if [ ${?} -ne ${RET_OK} ] ; then
		${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_FAILEDTORECV} ${0} ${LINENO} ${MSGWD_QMSG_REPRYTOSBY}
		exit ${RET_NG}
	fi 
fi

# postmasterプロセスの起動確認
RETRYCOUNT=0
while :
do
	tmp=`ps x | grep ${PNAME_POSTMASTER} | grep -v ${CMDNAME_GREP}`
	ret=${?}
	if [ ${ret} -eq ${RET_GREP_NOTFOUND} ] ; then
		if [ ${RETRYCOUNT} -lt ${RETRYCOUNTMAX} ]; then
			#プロセスがまだ起動していなければ1秒後に再確認
			RETRYCOUNT=`expr ${RETRYCOUNT} + 1`
			sleep 1
			continue
		else
			# 5回リトライしても存在しない場合、エラー
			${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_FAILEDTOBOOTPROCESS} ${0} ${LINENO} ${MSGWD_POSTMASTER}
			exit ${RET_NG}
		fi
	elif [ ${ret} -ne ${RET_OK} ]; then
		# grepコマンドエラー
		${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_ERRORGREP} ${0} ${LINENO}
		exit ${RET_NG}
	else
		# 正常
		break
	fi
done

# リカバリプロセスの生成を待機
while :
do
	tmp=`ps x | grep "${PNAME_POSTGRES_RECOVERY}" | grep -v ${CMDNAME_GREP}`
	ret=${?}
	if [ ${ret} -eq ${RET_OK} ] ; then
		# リカバリプロセスが存在
		break
	elif [ ${ret} -eq ${RET_ERR_GREP} ]; then
		# grepコマンドエラー
		${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_ERRORGREP} ${0} ${LINENO}
		exit ${RET_NG}
	fi
	
	# postmasterプロセスの生存を確認
	tmp=`ps x | grep ${PNAME_POSTMASTER} | grep -v ${CMDNAME_GREP}`
	ret=${?}
	if [ ${ret} -eq ${RET_GREP_NOTFOUND} ] ; then
		# postmasterプロセスが存在しない
		${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_FAILEDTOBOOTPROCESS} ${0} ${LINENO} ${MSGWD_POSTMASTER}
		exit ${RET_NG}
	elif [ ${ret} -eq ${RET_ERR_GREP} ]; then
		# grepコマンドエラー
		${PREX_BIN}/prexsyslog ${LOG_ERR} ${MSGID_CC_ERRORGREP} ${0} ${LINENO}
		exit ${RET_NG}
	fi
done

exit ${RET_OK}
