/*****************************************************************************
   Copyright (C) 2006 NTT
  *****************************************************************************/
/**
 * @file    mkmsgq.c
 * @brief   メッセージキュー作成コマンドのインプリメンテーション
 *
 * メッセージキュー作成コマンドのインプリメンテーションを行う。
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
 
#include <sys/msg.h>
#include <stdlib.h>
#include <string.h>
#include "PREXDefine.h"
#include "PREXMessage.h"
#include "mkmsgq.h"

/**
 * @fn      mkmsgq_main(int argc, char *argv[])
 * @brief   メッセージキュー作成コマンド・メイン処理
 *
 * メッセージキュー作成を行う。
 *
 *   詳細は以下のとおり。
 *     -# コマンドパラメータのチェックを行う。以下に示すパラメータ指定は、正常なパラメータとみなす。
 *        - 第1パラメータが指定されている、第2パラメータ以降は指定されていない。
 *     -# 正常なパラメータとみなせない場合には、エラーとして、syslogにエラーメッセージを出力後、戻り値としてRET_NGを返却して終了する。
 *     -# メッセージキューの作成を行う。
 *        エラーがあった場合、戻り値としてRET_NGを返却して終了する。
 *     -# 戻り値としてRET_OKを返却して終了する。
 *
 * @remarks     実際のメイン関数の名称は「main」であるが、ドキュメント生成ツールの仕様で他のソースに
 *              同名の関数があると正しく出力されないため、ここでは変更して記述している。
 * @param[in]   argc          引数の数
 * @param[in]   argv[0]       コマンド名
 * @param[in]   argv[1]       メッセージキューのキー値
 * @retval      RET_OK(0)   正常終了
 * @retval      RET_NG(1)   異常終了
 *
 * @version 1.0.0 
 * @date    09/01/2006
 * @since   1.0
 */
int main(int argc, char *argv[])
{

	/* メッセージキューのKEY */
	int msgkey;

	/* パラメータチェック */
	if (argc != 2) {
		/* メッセージキューのキーが指定されていない */
		OutputSyslog(LOG_ERR, MSGID_CC_ILLEGALPARAM, MSGWD_NUMOFPARAM);
		exit(RET_NG);
	}

	msgkey = atoi(argv[ARGINDEX_MSGQKEY]);

	/* メッセージキューの作成,取得 */
	if ((msgget((key_t)msgkey, MSGGET_FLG_RW | IPC_CREAT)) == MSGQ_ERROR) {
		OutputSyslog(LOG_ERR, MSGID_CC_FAILEDTOCREATEMSGQ);
		exit(RET_NG);
	}
	exit(RET_OK);

}
