/*****************************************************************************
   Copyright (C) 2006 NTT
  *****************************************************************************/
/**
 * @file    prexsyslog.c
 * @brief   SYSLOGメッセージ出力プロセスのインプリメンテーション
 *
 * SYSLOGメッセージ出力プロセスのインプリメンテーションを行う。
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#include <stdlib.h>
#include <string.h>
#include "PREXDefine.h"
#include "PREXMessage.h"
#include "prexsyslog.h"

/**
 * @fn      int prexsyslog_main(int argc , char *argv[])
 * @brief   SYSLOGメッセージ出力プロセス・メイン処理
 *
 *   SYSLOGへのメッセージ出力を行う。
 *
 *   詳細は以下のとおり。
 *     -# SYSLOGのオープン、書き込み、クローズを行う（PREX_SYSLOG マクロ）。
 *
 * @remarks     実際のメイン関数の名称は「main」であるが、ドキュメント生成ツールの仕様で他のソースに
 *              同名の関数があると正しく出力されないため、ここでは変更して記述している。
 * @param[in]   argc          引数の数
 * @param[in]   argv[0]       コマンド名
 * @param[in]   argv[1]       メッセージレベル
 * @param[in]   argv[2]       メッセージコード
 * @param[in]   argv[3]       ファイル名
 * @param[in]   argv[4]       行番号
 * @param[in]   argv[5]       メッセージ埋め込み文字列（省略可）
 * @param[in]   argv[6]       メッセージ埋め込み文字列（省略可）
 * @retval      RET_OK(0)   正常終了
 * @retval      RET_NG(1)   異常終了
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
int main(int argc , char *argv[])
{
	int priority;
	int lineno;
	if (argc < 5) {
		exit(RET_NG);
	}

	priority = atoi(argv[ARGINDEX_MSGLEVEL]);
	lineno = atoi(argv[ARGINDEX_LINE]);
	
	switch (argc) {
		case 5:
			OutputSyslogCore(priority, argv[ARGINDEX_MSGCODE], argv[ARGINDEX_FILE], lineno);
			break;

		case 6:
			OutputSyslogCore(priority, argv[ARGINDEX_MSGCODE], argv[ARGINDEX_FILE], lineno, argv[ARGINDEX_MSGSTR1]);
			break;

		case 7:
			OutputSyslogCore(priority, argv[ARGINDEX_MSGCODE], argv[ARGINDEX_FILE], lineno, argv[ARGINDEX_MSGSTR1], argv[ARGINDEX_MSGSTR2]);
			break;

		default :
			exit(RET_NG);
	}
	
	exit(RET_OK);
}
