/*****************************************************************************
   Copyright (C) 2006-2007 NTT
  *****************************************************************************/
/**
 * @file    GetCheckPointLSN.h
 * @brief   チェックポイントLSN取得に関する定数の定義
 * 
 * チェックポイントLSN取得に使用する定数を定義する。
 *
 * @version 1.1.0
 * @date    09/01/2006
 * @since   1.0
 */
#ifndef GETCHECKPOINTLSN_H_
#define GETCHECKPOINTLSN_H_

/*****************
 * 定数定義
 ****************/
/**
 * @def     CMN_CMD_GETCHECKPOINTLSN
 * @brief   チェックポイントLSN取得コマンド
 *
 * @attention Make時にGETCHECKPOINTを指定した場合は最終チェックポイントを
 *            指定しない場合は終端LSNを取得するコマンドを実行する
 *
 * @version 1.1.0
 * @date    08/01/2007
 * @since   1.0
 */
#ifdef	_GETCHECKPOINT
	#define CMN_CMD_GETCHECKPOINTLSN	"pg_controldata | grep '^Latest checkpoint.s REDO location:' | sed 's/^Latest checkpoint.s REDO location:[ ]*//g'"
#else
	#define CMN_CMD_GETCHECKPOINTLSN	"LastLSN"
#endif

/**
 * @def     CMN_CMDFMT_GETREMOTECHECKPOINTLSN
 * @brief   リモートホストのチェックポイントLSN取得コマンド生成用フォーマット
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define CMN_CMDFMT_GETREMOTECHECKPOINTLSN	"ssh %s@%s %s"

/**
 * @def     CMN_COMMANDMAX
 * @brief   コマンド最大長
 *
 * @attention 128という値は、コマンド生成用フォーマット内の可変部(%s)以外の文字列の長さを表す。
 *            コマンドを修正する場合は、値に注意すること。
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define CMN_COMMANDMAX	PREX_MAX_HOSTNAME_LEN + PREX_MAX_USERNAME_LEN + 128

/**
 * @def     ARGINDEX_HOST
 * @brief   ホスト名を示すargv[]のインデックス
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ARGINDEX_HOST	1

/**
 * @def     ARGINDEX_USER
 * @brief   ユーザ名を示すargv[]のインデックス
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ARGINDEX_USER	2

/*******************
 * プロトタイプ宣言
 ******************/
int GetCheckPointLSN(LSNInfo_t* pCheckPointLSN, char** arg);

#endif /* GETCHECKPOINTLSN_H_ */
