/*****************************************************************************
   Copyright (C) 2007-2008 NTT
  *****************************************************************************/
/** 
 * @file    LastLSN.h
 * @brief   I[LSN擾R}h̒萔̒`
 *
 * I[LSN擾R}hɎgp萔`B
 *
 * @version 1.3.0
 * @date    06/17/2008
 * @since   1.0
 */
#ifndef LASTLSN_H
#define LASTLSN_H


#define PGDATA "PGDATA"
#define CKPT_ARGC 1
#define WAL_ARGC 3

/** xlog.c **/

/* File path names (all relative to $PGDATA) */
#define BACKUP_LABEL_FILE		"backup_label"
#define BACKUP_LABEL_OLD		"backup_label.old"
#define RECOVERY_COMMAND_FILE	"recovery.conf"
#define RECOVERY_COMMAND_DONE	"recovery.done"

/* Sync methods */
//#define SYNC_METHOD_FSYNC		0
//#define SYNC_METHOD_FDATASYNC	1
//#define SYNC_METHOD_OPEN		2		/* for O_SYNC and O_DSYNC */
//#define SYNC_METHOD_FSYNC_WRITETHROUGH	3
//#define DEFAULT_SYNC_METHOD		SYNC_METHOD_FSYNC

/* these are derived from XLOG_sync_method by assign_xlog_sync_method */
int			sync_method = DEFAULT_SYNC_METHOD;

/*
 * We maintain an image of pg_control in shared memory.
 */
static ControlFileData *ControlFile = NULL;

/* Was the last xlog file restored from archive, or local? */
static bool restoredFromArchive = false;

/* options taken from recovery.conf */
static char *recoveryRestoreCommand = NULL;

/*
 * During normal operation, the only timeline we care about is ThisTimeLineID.
 * During recovery, however, things are more complicated.  To simplify life
 * for rmgr code, we keep ThisTimeLineID set to the "current" timeline as we
 * scan through the WAL history (that is, it is the line that was active when
 * the currently-scanned WAL record was generated).  We also need these
 * timeline values:
 *
 * recoveryTargetTLI: the desired timeline that we want to end in.
 *
 * expectedTLIs: an integer list of recoveryTargetTLI and the TLIs of
 * its known parents, newest first (so recoveryTargetTLI is always the
 * first list member).	Only these TLIs are expected to be seen in the WAL
 * segments we read, and indeed only these TLIs will be considered as
 * candidate WAL files to open at all.
 *
 * curFileTLI: the TLI appearing in the name of the current input WAL file.
 * (This is not necessarily the same as ThisTimeLineID, because we could
 * be scanning data that was copied from an ancestor timeline when the current
 * file was created.)  During a sequential scan we do not allow this value
 * to decrease.
 */
static TimeLineID recoveryTargetTLI;
static List *expectedTLIs;
static TimeLineID curFileTLI;

/*
 * RedoRecPtr is this backend's local copy of the REDO record pointer
 * (which is almost but not quite the same as a pointer to the most recent
 * CHECKPOINT record).	We update this from the shared-memory copy,
 * XLogCtl->Insert.RedoRecPtr, whenever we can safely do so (ie, when we
 * hold the Insert lock).  See XLogInsert for details.	We are also allowed
 * to update from XLogCtl->Insert.RedoRecPtr if we hold the info_lck;
 * see GetRedoRecPtr.  A freshly spawned backend obtains the value during
 * InitXLOGAccess.
 */
static XLogRecPtr RedoRecPtr;

/*
 * ThisTimeLineID will be same in all backends --- it identifies current
 * WAL timeline for the database system.
 */
TimeLineID	ThisTimeLineID = 0;

/* Are we recovering using offline XLOG archives? */
static bool InArchiveRecovery = false;

/*
 * These variables are used similarly to the ones above, but for reading
 * the XLOG.  Note, however, that readOff generally represents the offset
 * of the page just read, not the seek position of the FD itself, which
 * will be just past that page.
 */
static int	readFile = -1;
static uint32 readId = 0;
static uint32 readSeg = 0;
static uint32 readOff = 0;

/* Buffer for currently read page (XLOG_BLCKSZ bytes) */
static char *readBuf = NULL;

/* Buffer for current ReadRecord result (expandable) */
static char *readRecordBuf = NULL;
static uint32 readRecordBufSize = 0;

/* State information for XLOG reading */
static XLogRecPtr ReadRecPtr;	/* start of last record read */
static XLogRecPtr EndRecPtr;	/* end+1 of last record read */
static XLogRecord *nextRecord = NULL;
static TimeLineID lastPageTLI = 0;
/* 200806 -> */
static bool InRedo = false;
/* <- 200806 */
/* src/backend/access/transam/xlog.c */

/* ֐` */
static int	XLogFileRead(uint32 log, uint32 seg, int emode);
static void readRecoveryCommandFile(void);
static void exitArchiveRecovery(TimeLineID endTLI,
					uint32 endLogId, uint32 endLogSeg);
static void ReadControlFile(void);
static bool RestoreArchivedFile(char *path, const char *xlogfname,
					const char *recovername, off_t expectedSize);
static XLogRecord *ReadRecord(XLogRecPtr *RecPtr, int emode);
static bool ValidXLOGHeader(XLogPageHeader hdr, int emode);
static XLogRecord *ReadCheckpointRecord(XLogRecPtr RecPtr, int whichChkpt);
//static bool read_backup_label(XLogRecPtr *checkPointLoc,
//				  XLogRecPtr *minRecoveryLoc);
static bool RecordIsValid(XLogRecord *record, XLogRecPtr recptr, int emode);
static List *readTimeLineHistory(TimeLineID targetTLI);
/* 200806 -> */
static bool existsTimeLineHistory(TimeLineID probeTLI);
static TimeLineID findNewestTimeLine(TimeLineID startTLI);
/* <- 200806 */

/** list.c **/
#define IsIntegerList(l)		((l) == NIL || IsA((l), IntList))

bool list_member_int(List *list, int datum);
List * lcons_int(int datum, List *list);
static List * new_list(NodeTag type);
static void new_head_cell(List *list);

/** fd.c **/

/* Debugging.... */

#ifdef FDDEBUG
#define DO_DB(A) A
#else
#define DO_DB(A)				/* A */
#endif
#define VFD_CLOSED (-1)
#define MAX_ALLOCATED_DESCS  32

typedef enum
{
	AllocateDescFile,
	AllocateDescDir
} AllocateDescKind;

typedef struct
{
	AllocateDescKind kind;
	union
	{
		FILE	   *file;
		DIR		   *dir;
	}			desc;
	SubTransactionId create_subid;
} AllocateDesc;

typedef struct vfd
{
	signed short fd;			/* current FD, or VFD_CLOSED if none */
	unsigned short fdstate;		/* bitflags for VFD's state */
	SubTransactionId create_subid;		/* for TEMPORARY fds, creating subxact */
	File		nextFree;		/* link to next free VFD, if in freelist */
	File		lruMoreRecently;	/* doubly linked recency-of-use list */
	File		lruLessRecently;
	long		seekPos;		/* current logical file position */
	char	   *fileName;		/* name of file, or NULL for unused VFD */
	/* NB: fileName is malloc'd, and must be free'd when closing the VFD */
	int			fileFlags;		/* open(2) flags for (re)opening the file */
	int			fileMode;		/* mode to pass to open(2) */
} Vfd;


static int	numAllocatedDescs = 0;
/*
 * Number of file descriptors known to be in use by VFD entries.
 */
static int	nfile = 0;
static AllocateDesc allocatedDescs[MAX_ALLOCATED_DESCS];
static int	max_safe_fds = 32;	/* default if not changed */
static Vfd *VfdCache;

FILE * AllocateFile(const char *name, const char *mode);
static bool ReleaseLruFile(void);
static void LruDelete(File file);
static void Delete(File file);
int BasicOpenFile(FileName fileName, int fileFlags, int fileMode);
int FreeFile(FILE *file);
static int FreeDesc(AllocateDesc *desc);
int pg_fsync(int fd);
int pg_fsync_no_writethrough(int fd);
int pg_fsync_writethrough(int fd);

/** guc.c **/
/*
 * CurrentMemoryContext
 *		Default memory context for allocations.
 */
MemoryContext CurrentMemoryContext = NULL;
void SetConfigOption(const char *name, const char *value,
				GucContext context, GucSource source);

#define DatumGetAbsoluteTime(X)  (0)




/** globals.c **/
bool		enableFsync = true;
SubTransactionId GetCurrentSubTransactionId(void);

/* mcxt.c */
void pfree(void *pointer);
char * MemoryContextStrdup(MemoryContext context, const char *string);

/* pg_locale.c */
/* Environment variable storage area */

#define LC_ENV_BUFSIZE (LOCALE_NAME_BUFLEN + 20)

static char lc_collate_envbuf[LC_ENV_BUFSIZE];
static char lc_ctype_envbuf[LC_ENV_BUFSIZE];

#ifdef LC_MESSAGES
static char lc_messages_envbuf[LC_ENV_BUFSIZE];
#endif
static char lc_monetary_envbuf[LC_ENV_BUFSIZE];
static char lc_numeric_envbuf[LC_ENV_BUFSIZE];
static char lc_time_envbuf[LC_ENV_BUFSIZE];

#endif   /* XLOG_H */
