/*****************************************************************************
   Copyright (C) 2006-2008 NTT
  *****************************************************************************/
/**
 * @file    PREXMessage.h
 * @brief   PREX共通定義
 *
 * PREXにおけるモジュール間で、共通に使用するテーブル及び定数を定義する。
 *
 * @version 1.3.0
 * @date    06/17/2008
 * @since   1.0
 */
#ifndef PREXMESSAGE_H_
#define PREXMESSAGE_H_

/* テーブル定義 */
/**
 * @struct  MessageInfo_t
 * @brief   メッセージ情報
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
typedef struct MessageInfo_t {
	char* ID;                             ///< メッセージID
	char* format;                         ///< メッセージフォーマット
	char* level;                          ///< メッセージレベル
} MessageInfo_t;

/**
 * @struct  FunctionInfo_t
 * @brief   メッセージコードの発生箇所（機能番号）と対応する機能情報
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
typedef struct FunctionInfo_t {
	char* ID;                             ///< 機能ID
	char* name;                           ///< 機能名
} FunctionInfo_t;

/************************************************
 * メッセージID
 ***********************************************/
#define MSGID_WWMSG_ILLEGALPARAM  "08900001"
#define MSGID_WWMSG_FAILEDTORECVMSGFROMQUE  "08900012"
#define MSGID_WWMSG_FAILEDTOSENDMSGTOQUE    "08900018"
#define MSGID_WWMSG_FAILEDTOGETMSGQUE  "08900008"
#define MSGID_WWMSG_ACTBEFORESYNCBACKUP "08900064"
#define MSGID_WWMSG_NOTACTMSGRECVED    "08900071"
#define MSGID_WWWRT_ILLEGALPARAM  "07900001"
#define MSGID_WWWRT_FAILEDTOGETMSGQUE  "07900008"
#define MSGID_WWWRT_FAILEDTOOPENFILE  "07900003"
#define MSGID_WWWRT_FAILEDTOSEEKFILE  "07900002"
#define MSGID_WWWRT_FAILEDTOWRITEFILE "07900004"
#define MSGID_WWWRT_FAILEDTOSENDMSGTOQUE  "07900018"
#define MSGID_WWCOM_STARTWALWRITER       "06000068"
#define MSGID_WWCOM_FAILEDTOSENDMSGTOQUE  "06900018"
#define MSGID_WWCOM_FAILEDTOGETMSGQUE  "06900008"
#define MSGID_WWCOM_FAILEDTOALLOCMEM "06900056"
#define MSGID_WWCOM_ILLEGALPARAM  "06900001"
#define MSGID_WWCOM_FAILEDTOGETENV  "06900010"
#define MSGID_WWCOM_FAILEDTOCREATESOCKET  "06900052"
#define MSGID_WWCOM_FAILEDTOGETHOST  "06900010"
#define MSGID_WWCOM_FAILEDTOSTARTTHREAD  "06900011"
#define MSGID_WWCOM_CONNECTIONCLOSED  "06900022"
#define MSGID_WWCOM_FAILEDTORECVFROMWS  "06900012"
#define MSGID_WWCOM_FAILEDTOSENDTOWS    "06900018"
#define MSGID_WWCOM_RECVILLEGALMSG  "06900013"
#define MSGID_WWCOM_FAILEDTODECMPFUNC  "06900015"
#define MSGID_WWCOM_FAILEDTODECOMPRESS "06900101"
#define MSGID_CMN_FAILEDTOOPENFILE  "10900003"
#define MSGID_CMN_FAILEDTOREADFILE  "10900002"
#define MSGID_CMN_FAILEDTOCRTLLOCK  "10900058"
#define MSGID_CMN_ILLEGALPARAM  "10900001"
#define MSGID_CMN_FAILEDTOALLOCMEM "10900056"
#define MSGID_WS_STARTWALSENDER     "05000068"
#define MSGID_WS_PGMODECHANGED      "05000069"
#define MSGID_WS_FAILEDTOGETMSGQUE  "05900008"
#define MSGID_WS_CONNECTIONCLOSED  "05900022"
#define MSGID_WS_FAILEDTOSENDTOWW  "05900018"
#define MSGID_WS_FAILEDTOALLOCMEM "05900056"
#define MSGID_WS_ILLEGALPARAM  "05900001"
#define MSGID_WS_FAILEDTOCREATESOCKET  "05900052"
#define MSGID_WS_FAILEDTOREADYTOLISTEN  "05900025"
#define MSGID_WS_FAILEDTOACCEPT  "05900024"
#define MSGID_WS_FAILEDTOOPENFILE "05900003"
#define MSGID_WS_FAILEDTOREADFILE "05900002"
#define MSGID_WS_FAILEDTODELETEFILE "05900009"
#define MSGID_WS_FAILEDTORECVFROMWW  "05900012"
#define MSGID_WS_RECVILLEGALMSG  "05900013"
#define MSGID_WS_CONNECTIONTIMEDOUT  "05900023"
#define MSGID_WS_FAILEDTOSENDMSGTOQUE  "05900018"
#define MSGID_WS_FAILEDTORECVMSGFROMQUE  "05900012"
#define MSGID_WS_FAILEDTOATTACHSHAREDMEM  "05900049"
#define MSGID_WS_FAILEDTOGETENV  "05900010"
#define MSGID_WS_FAILEDTOWRITEFILE "05900004"
#define MSGID_WS_PROCESSNOTEXISTS "05900038"
#define MSGID_WS_FAILEDTOCMPFUNC  "05900014"
#define MSGID_WS_CREATEFOFILE  "05900083"
#define MSGID_WS_DELETEFOFILE  "05900084"
#define MSGID_WS_FAILEDTOCOMPRESS "05900100"

#define MSGID_PM_ILLEGALPARAM       "02900001"
#define MSGID_PM_PGMODECHANGED      "02000069"
#define MSGID_PM_FAILEDTOGETMSGQUE  "02900008"
#define MSGID_PM_FAILEDTOSENDMSGTOQUE  "02900018"
#define MSGID_PM_FAILEDTOSTARTWALSENDER  "02900040"
#define MSGID_PM_FAILEDTOATTACHSHAREDMEM  "02900049"
#define MSGID_PM_ILLEGALTERMOFWALSENDER   "02900045"
#define MSGID_PG_FAILEDTOGETMSGQUE          "03900008"
#define MSGID_PG_FAILEDTOSENDMSGTOQUE       "03900018"
#define MSGID_PG_FAILEDTORECVMSGFROMQUE     "03900012"
#define MSGID_PG_MSGQUEWASREMOVED           "03900005"
#define MSGID_PGRCV_FAILEDTOARCHIVEXLOG     "04900066"
#define MSGID_PGRCV_FAILEDTOUNLINK          "04900009"
#define MSGID_PGRCV_FAILEDTOGETMSGQUE       "04900008"
#define MSGID_PGRCV_FAILEDTORECVMSGFROMQUE  "04900012"
#define MSGID_PGRCV_STARTUPPREXMODE         "04000067"
#define MSGID_PGRCV_MSGQUEWASREMOVED        "04900005"
#define MSGID_PGRCV_INVALIDWALSEGMENT       "04900070"
#define MSGID_HAIF_ILLEGALPARAM             "00900001"
#define MSGID_HAIF_FAILEDTOOPENFILE         "00900003"
#define MSGID_HAIF_FAILEDTOALLOCMEM         "00900056"
#define MSGID_CC_DEBUG                      "01900000"
#define MSGID_CC_ILLEGALPARAM               "01900001"
#define MSGID_CC_FAILEDTOCREATEMSGQ         "01900007"
#define MSGID_CC_FAILEDTOGETMSGQ            "01900008"
#define MSGID_CC_FAILEDTOGET                "01900010"
#define MSGID_CC_FAILEDTORECV               "01900012"
#define MSGID_CC_RECVILLEGALMSG             "01900013"
#define MSGID_CC_RECVMSGRETISNG             "01900017"
#define MSGID_CC_FAILEDTOSEND               "01900018"
#define MSGID_CC_FAILEDTORSYNC              "01900019"
#define MSGID_CC_FAILEDTOACCEPT             "01900024"
#define MSGID_CC_FAILEDTOSETTINGRECVWAIT    "01900025"
#define MSGID_CC_FAILEDTOSYNCXLOG           "01900035"
#define MSGID_CC_FAILEDTOCONNECTSSH         "01900043"
#define MSGID_CC_FAILEDTODISCONNECTSSH      "01900044"
#define MSGID_CC_FAILEDTOREADCONFIG         "01900050"
#define MSGID_CC_FAILEDTOOPENSOCKET         "01900052"
#define MSGID_CC_WARNINGWAITTOACT           "01900062"
#define MSGID_WWGET_ILLEGALPARAM            "09900001"
#define MSGID_WWGET_FAILEDTOGETMSGQ         "09900008"
#define MSGID_WWGET_FAILEDTOGET             "09900010"
#define MSGID_WWGET_FAILEDTOSEND            "09900018"
#define MSGID_WWGET_FAILEDTORSYNC           "09900019"
#define MSGID_WWGET_ERRORGREP               "09900032"
#define MSGID_WWGET_FAILEDTOBOOTPROCESS     "09900040"
#define MSGID_WWGET_WARNINGRETRYRSYNC       "09900063"
#define MSGID_CMN_DEBUG                     "10900000"
#define MSGID_CMN_FAILEDTOGET               "10900010"
#define MSGID_CMN_FAILEDTOSMGOPEN           "10900078"
#define MSGID_CMN_FAILEDTOSMGCLOSE          "10900079"
#define MSGID_CMN_FAILEDTOSMGUNLINK         "10900080"
#define MSGID_CMN_FAILEDTOSMGLOCK           "10900081"
#define MSGID_CMN_FAILEDTOSMGUNLOCK         "10900082"
#define MSGID_CMN_FAILEDLASTLSN             "10900096"
#define MSGID_CMN_FAILEDTOOPENFILE          "10900003"
#define MSGID_CMN_FAILEDTOREADFILE          "10900002"
#define MSGID_CMN_ILLEGALPARAM              "10900001"
#define MSGID_CMN_FAILEDTOALLOCMEM          "10900056"
#define MSGID_CMN_FAILEDTOACCESSDIR         "10900097"
#define MSGID_CMN_NOFILEEXISTS              "10900098"
#define MSGID_CMN_ILLEGALFILE               "10900099"


/************************************************
 * メッセージの引数
 ***********************************************/
#define PREX_MODNAME_WW  "WALWriter"
#define PREX_MODNAME_WS  "WALSender"
#define PREX_MODNAME_CC  "ClusterCommands"
#define PREX_MODNAME_PM  "postmaster"
#define PREX_MODNAME_PG  "postgres"
#define PREX_MODNAME_PGRCV  "postgres(recovery)"
#define ENVITEM_MSGQID   "MessageQueue-ID"
#define ENVITEM_MSGKEY      "EnvItem(prex_msgkey)"
#define ENVITEM_PORT        "EnvItem(prex_port)"
#define ENVITEM_TIMEOUT     "EnvItem(prex_timeout)"
#define ENVITEM_FOFILEPATH  "EnvItem(prex_fo_control_filepath)"
#define ENVITEM_ACTWALHOST  "EnvItem(actwalhost)"
#define ENVITEM_ACTWALUSER  "EnvItem(actwaluser)"
#define ENVITEM_ACTWALDIR  "EnvItem(actwaldir)"
#define ENVITEM_SBYWALDIR  "EnvItem(sbywaldir)"
#define ENVITEM_ACTARCHIVEHOST  "EnvItem(actarchivehost)"
#define ENVITEM_ACTARCHIVEUSER  "EnvItem(actarchiveuser)"
#define ENVITEM_ACTARCHIVEDIR  "EnvItem(actarchivedir)"
#define ENVITEM_SBYARCHIVEDIR  "EnvItem(sbyarchivedir)"
#define MSGQITEM_TOACT   "activation message"
#define MSGQITEM_TOACTORPITR  "activation or resume-recovery message"
/* 200806 -> */
#define MSGQITEM_TOTLI   "TLI message"
#define MSGQITEM_RECEIVETLI  "receive TLI"
/* <- 200806 */
#define MSGQITEM_REPLYOFTOACT "reply to activation message"
#define MSGQITEM_REPLYOFTOSBY "reply to go-standby message"
#define MSGQITEM_REPLYOFBKUPFINISHED "reply to backup-completion message"
#define MSGQITEM_ORDERTOSENDWAL "trigger message for sending WAL record"
#define MSGITEM_SENDWAL  "WAL record"
/* 200806 -> */
#define MSGITEM_SENDTLI  "TLI"
#define MSGITEM_SENDHISTORY  "history file"
#define MSGITEM_REPLYOFSENDWAL  "reply to WAL record"
#define MSGITEM_REPLYOFSENDTLI  "reply to TLI"
#define MSGITEM_REPLYOFSENDHISTORY  "reply to history file"
/* <- 200806 */
#define MSGITEM_REQUESTTOSTARTSEND  "request to start sending WAL record"
#define MSGITEM_LASTLSNINFO  "last LSN information"
#define MSGITEM_SENDWALFINISHED  "notice of completion sending WAL record"
#define WALSEGMENTFILE   "WALSegment file"
#define NUM_OF_ARGUMENTS "number of arguments"
#define ENVVAL_USER   "USER environment variable"
#define ENVVAL_HOME   "HOME environment variable"
#define WS_HOST_INFO  "information of ws_host"
#define WW_MSGTHREAD  "message thread"
#define WW_WRTTHREAD  "writer thread"
#define WW_GTRTHREAD  "backup getting thread"
#define MSGWD_REMOTELSN                     "remote LSN"
#define MSGWD_LOCALLSN                      "local LSN"
#define MSGWD_QMSG_REPLYTOACT               "result of activation message"
#define MSGWD_TCPMSG_ENDSYNCXLOG            "notice of completion syncing WAL directory"
#define MSGWD_QMSG_TOACT                    "activation message"
#define MSGWD_WALDIR                        "wal directory"
#define MSGWD_ARCHIVEDIR                    "archive directory"
#define MSGWD_WWGETTERTHREADINFO            "WWGetterThreadInfo"
#define MSGWD_WWMESSAGETHREADINFO           "WWMessageThreadInfo"
#define MSGWD_SENDENDLSN                    "file transfer end location LSN"
#define MSGWD_CHECKPOINTLSN                 "checkpoint location LSN"
#define MSGWD_QMSG_REPLYTOSBY               "result of go-standby message"
#define MSGWD_QMSG_REQUESTTOPITR            "resume-recovery message"
#define MSGWD_QMSG_BKUPFINISHED             "backup-completion message"
#define MSGWD_ARCHIVELOG                    "archive log"
#define MSGWD_BASEBACKUP                    "backup database cluster"
#define MSGWD_BACKUPHISTORYFILE             "backup history file"
#define MSGWD_POSTMASTER                    "postmaster"
#define MSGWD_CHECKPOINTLSN                 "checkpoint location LSN"
#define MSGWD_NUMOFPARAM                    "number of parameters"
#define MSGWD_CONN_HOSTNAME                 "connect host name"
#define MSGWD_CONN_USERNAME                 "connect host user"
#define MSGWD_CONN_PORTNO                   "connect port number"
#define MSGWD_CONN_POLLING_INTERVAL         "connect polling interval"
#define INTERNAL_PARAMETERS                 "internal parameters"
#define MSGWD_PGMODE_SBY                    "standby"
#define MSGWD_PGMODE_ACT_SA                 "active (standalone mode)"
#define MSGWD_PGMODE_ACT_REP                "active (replication mode)"
#define MSGWD_EXCLUSIVELOCK                 "exclusive_lock"
#define MSGWD_GETENV                        "acquisition of the environment variable was failed"
#define MSGWD_CHDIR                         "failed to change directory"
#define MSGWD_LASTLSN                       "LastLSN method returned error"
#define MSGWD_ASSERT                        "Assert method returned error"
#define MSGWD_INVALIDHEADER                 "invalid page header at WAL segment file"
#define MSGWD_NOWALSEGMENT                  "WAL segment file is not exists"
#define MSGWD_INVALIDSIZE                   "invalid file size"

/************************************************
 * グローバル変数定義
 ***********************************************/
extern MessageInfo_t PREXMsgInfo[];
extern FunctionInfo_t PREXFuncInfo[];

#endif  /* PREXMESSAGE_H_ */
