/*****************************************************************************
   Copyright (C) 2007 NTT
  *****************************************************************************/
/** 
 * @file    Semaphore.h
 * @brief   セマフォ管理コマンドに関する定数の定義
 *
 * セマフォ管理コマンドに使用する定数を定義する。
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#ifndef SEMAPOHORE_H_
#define SEMAPOHORE_H_

/*****************
 * 定数定義
 ****************/
 
/**
 * @def     SEM_CREATE_ACT_WORD
 * @brief   ACT監視抑止ファイル用セマフォの作成時のキーワード
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#define SEM_CREATE_ACT_WORD	"/prex_act_semaphore"
 
/**
 * @def     SEM_CREATE_SBY_WORD
 * @brief   SBY監視抑止ファイル用セマフォの作成時のキーワード
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#define SEM_CREATE_SBY_WORD	"/prex_sby_semaphore"
 
/**
 * @def     SEM_CREATE_FO_WORD
 * @brief   フェールオーバ抑止ファイル用セマフォの作成時のキーワード
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#define SEM_CREATE_FO_WORD	"/prex_fo_semaphore"

/**
 * @def     SEM_ERROR
 * @brief   セマフォの作成時の返り値(エラー)
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#define SEM_ERROR	-1

/**
 * @def     SEM_INIT_VALUE
 * @brief   セマフォの初期値
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#define SEM_INIT_VALUE	1

/**
 * @def     SMG_OPEN_COMMAND
 * @brief   セマフォ作成コマンドID
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#define SMG_OPEN_COMMAND	1

/**
 * @def     SMG_UNLINK_COMMAND
 * @brief   セマフォ解放コマンドID
 *
 * @note セマフォ解放コマンドIDの値は、SMG_OPEN_COMMANDの値に1加算した
 *       ものである必要がある
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#define SMG_UNLINK_COMMAND	2

/**
 * @def     SMG_ACT_LOCK_COMMAND
 * @brief   ACTセマフォロックコマンドID
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#define SMG_ACT_LOCK_COMMAND	3

/**
 * @def     SMG_ACT_UNLOCK_COMMAND
 * @brief   ACTセマフォロック解除コマンドID
 *
 * @note ACTセマフォロック解除コマンドIDの値は、SMG_ACT_LOCK_COMMANDの値に1加算した
 *       ものである必要がある
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#define SMG_ACT_UNLOCK_COMMAND	4

/**
 * @def     SMG_SBY_LOCK_COMMAND
 * @brief   SBYセマフォロックコマンドID
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#define SMG_SBY_LOCK_COMMAND	5

/**
 * @def     SMG_SBY_UNLOCK_COMMAND
 * @brief   SBYセマフォロック解除コマンドID
 *
 * @note SBYセマフォロック解除コマンドIDの値は、SMG_SBY_UNLOCK_COMMANDの値に1加算した
 *       ものである必要がある
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#define SMG_SBY_UNLOCK_COMMAND	6

/**
 * @def     SMG_FO_LOCK_COMMAND
 * @brief   FOセマフォロックコマンドID
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#define SMG_FO_LOCK_COMMAND	7

/**
 * @def     SMG_FO_UNLOCK_COMMAND
 * @brief   FOセマフォロック解除コマンドID
 *
 * @note FOセマフォロック解除コマンドIDの値は、SMG_FO_UNLOCK_COMMANDの値に1加算した
 *       ものである必要がある
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#define SMG_FO_UNLOCK_COMMAND	8

#endif /* READCONFIG_H_ */
