/*****************************************************************************
   Copyright (C) 2007 NTT
  *****************************************************************************/
/**
 * @file    LastLSNMain.c
 * @brief   終端LSN取得コマンド主制御
 *
 *終端LSNを取得するコマンドの主制御(main)を提供する。
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
#include "postgres.h"
#include "access/xlog_internal.h"


extern int LastLSN_main(int argc, char *argv[], XLogRecPtr *lastLSN);

/**
 * @fn      int LastLSN_main(int argc, char *argv[])
 * @brief   終端LSN取得コマンド・メイン処理
 *
 * 終端LSNの取得のコマンドを提供する。LastLSN_main関数を呼び出し、
 * その結果を返却する。
 *
 *
 * @param[in]   argc          引数の数
 * @param[in]   argv[0]       Logid(10進数)
 * @param[in]   argv[1]       Logseg(10進数)
 * @retval      RET_OK(0)     正常終了
 * @retval      RET_NG(1)     異常終了
 *
 * @version 1.0.0
 * @date    08/01/2007
 * @since   1.0
 */
int main(int argc, char *argv[])
{
    int ret;                           /* 諸関数の戻り値 */
    XLogRecPtr lastLSN;                /* 終端LSN        */
    
    ret = LastLSN_main(argc, argv, &lastLSN);
    if(ret == 0) {
    	printf("%X/%X\n", lastLSN.xlogid, lastLSN.xrecoff);
    }
    return ret;
}

