/*****************************************************************************
   Copyright (C) 2006-2008 NTT
  *****************************************************************************/
/**
 * @file    WWCommThread.h
 * @brief   WALWriterの通信スレッドに関する関数の宣言
 *
 * WALWriterの通信スレッドにおいて使用する関数を宣言する。
 *
 * @version 1.3.0
 * @date    06/17/2008
 * @since   1.0
 */
#ifndef WWCOMMTHREAD_H_
#define WWCOMMTHREAD_H_

#include "ReadWWConfFile.h"

/************
 * 定数定義
 ***********/
/**
 * @def     WW_MAX_LEGAL_ARGC
 * @brief   有効な実行時引数の最大値
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define WW_MAX_LEGAL_ARGC   2

/**
 * @def     WW_MIN_LEGAL_ARGC
 * @brief   有効な実行時引数の最小値
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define WW_MIN_LEGAL_ARGC   1

/**
 * @def   WAIT_BEFORE_CONNECT_USECVAL
 * @brief WALSender との接続前の一時停止時間
 *
 * @note  単位はマイクロ秒。
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define WAIT_BEFORE_CONNECT_USECVAL  200000

/**
 * @def     WWPRM_INIT
 * @brief   実行時引数（初期起動パラメータ）
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define WWPRM_INIT    "-i"

/**
 * @def     ENVITEM_USER
 * @brief   環境変数名（USER）
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ENVITEM_USER   "USER"

/**
 * @def     ENVITEM_HOME
 * @brief   環境変数名（HOME）
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define ENVITEM_HOME   "HOME"

/**
 * @def     PREX_HOMENAME
 * @brief   PREXホームディレクトリ名
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
 */
#define PREX_HOMENAME   "prex"

/**
 * @def     WWCOMM_CMDFMT_CHECKENABLETOACT
 * @brief   ACT化可否判断コマンド生成用フォーマット
 *
 * @version 1.1.0
 * @date    10/30/2007
 * @since   1.1
 */
#define WWCOMM_CMDFMT_CHECKENABLETOACT	"check_enable_toact.sh %d %s %s %d %d"


/**
 * @def     CMN_COMMANDMAX
 * @brief   ACT化可否判断コマンド生成用文字列格納領域
 *
 * @version 1.1.0
 * @date    10/30/2007
 * @since   1.1
 */
#define CMN_COMMANDMAX	512

/********************
 * プロトタイプ宣言
 *******************/
int InitWWCommThread(int argc, char **argv);
void TermWWCommThread();
int CheckConfiguration(int argc, char **argv);
LineType_t GetConfLineType (char* bufLine);
int ConnectToWALSender();
void DisconnectWALSender();
int StartWWMessageThread();
int StartWWWriterThread();
int StartWWGetterThread();
int ReceiveWAL();
int SendRequestToStartSending();
int SendReplyOfSendingWAL(int nResult);
int ReceiveLastLSNFromWALSender(LSNInfo_t* pLastLSN);
int ReceiveHeaderAndLSNFromWALSender(CommWALInfo_t* pCommInfo);
int ReceiveWALFromWALSender(int nTotalBlock, CommWALInfo_t* pCommInfo);
int DecompressWAL(CommWALInfo_t* pCommInfo, char **decompressedWALBuffer);
int RecvCurrentWAL(CommWALInfo_t* pCommInfo, char **recvWALBuffer);
/* 200806 -> */
int ReceiveTLI();
int SendReplyOfSendingTLI();
int ReceiveHistory();
int SendReplyOfSendingHistory();
/* <- 200806 */

/*****************
 * マクロ関数定義
 ****************/
/**
 * @def UpdateCurrentWritePosition()
 * @brief   格納先ブロック位置更新
 *
 *   現在の格納先ブロック位置を更新する。
 *
 *   詳細は以下のとおり。
 *     -# 登録WAL情報リスト上の格納先ブロック位置に関するWAL情報を取得する
 *        （GetWALInfo 関数）。
 *     -# 格納先ブロック位置を更新する。
 *        格納先ブロック位置 =
 *            （格納先ブロック位置 +（1 で取得した登録WAL情報のブロック数））%
 *            WALWriter用WALバッファにおけるブロック数(ww_buffers)
 *
 * @note    登録WAL情報リストから、現在の書き込み対象WALの使用ブロック数を取得し、
 *          次の格納先ブロック位置を算出する。
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
*/
#define UpdateCurrentWritePosition() { \
	RegWALInfo_t*  pWALInfo__; \
	pWALInfo__ = GetWALInfo(WWCommThRc.nTargetPos); \
	WWCommThRc.nTargetPos = \
		(WWCommThRc.nTargetPos + pWALInfo__->nRequiredBlocks) % g_WWEnvInfo.ww_buffers; \
}

#endif /* WWCOMMTHREAD_H_ */
