/*****************************************************************************
   Copyright (C) 2006-2008 NTT
  *****************************************************************************/
/**
 * @file    WWMessageThread.h
 * @brief   WALWriterのメッセージスレッドに関する関数の宣言
 *
 * WALWriterのメッセージスレッドにおいて使用する関数を宣言する。
 *
 * @version 1.3.0
 * @date    07/25/2008
 * @since   1.0
 */

#ifndef WWMESSAGETHREAD_H_
#define WWMESSAGETHREAD_H_

#include "PREXDefine.h"

/********************
 * プロトタイプ宣言
 *******************/
void *WWMessageThreadMain(void* arg);
int InitWWMessageThread(WWMessageThreadInfo_t* pMsgThRc);
int ReceiveMessageToACTFromQueue(int nMsgQueID, LSNInfo_t *lsn);
int SendMessageToACTToQueue(int nMsgQueID, LSNInfo_t *lsn);

/*****************
 * マクロ関数定義
 ****************/

/**
 * @def     WaitForGettingBackupCompleted()
 * @brief   バックアップ取得完了待ち
 *
 *   バックアップ取得スレッドにおけるバックアップ取得が完了するまで待機する。
 *
 *   詳細は以下のとおり。
 *     -# バックアップ取得完了フラグが「偽」の場合、状態変数を用いて、
 *        バックアップ取得完了フラグが「真」に更新されるまで待機する。
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
*/
#define WaitForGettingBackupCompleted() {\
	pthread_mutex_lock(&(g_WWCmnInfo.GettingBackupInfo.mutex));\
	while (g_WWCmnInfo.GettingBackupInfo.nFlag == FALSE) {\
		pthread_cond_wait(&(g_WWCmnInfo.GettingBackupInfo.cond), &(g_WWCmnInfo.GettingBackupInfo.mutex));\
	}\
	pthread_mutex_unlock(&(g_WWCmnInfo.GettingBackupInfo.mutex));\
}

/**
 * @def     WaitForWALBufferEmpty()
 * @brief   WAL受信待ち状態待ち
 *
 *   WALWriter用WALバッファに存在するすべてのWALの書き込みが完了するまで待機する。
 *
 *   詳細は以下のとおり。
 *     -# WAL受信待ち状態フラグが「偽」の場合、状態変数を用いて、
 *        WAL受信待ち状態フラグが「真」に更新されるまで待機する。
 *
 * @version 1.0.0
 * @date    09/01/2006
 * @since   1.0
*/
#define WaitForWALBufferEmpty() {\
	pthread_mutex_lock(&(g_WWCmnInfo.WALBufferInfo.mutex));\
	while (g_WWCmnInfo.WALBufferInfo.nFlag == FALSE) {\
		pthread_cond_wait(&(g_WWCmnInfo.WALBufferInfo.cond), &(g_WWCmnInfo.WALBufferInfo.mutex));\
	}\
	pthread_mutex_unlock(&(g_WWCmnInfo.WALBufferInfo.mutex));\
}

/**
 * @def     WaitForCheckEnableToact()
 * @brief   ACT化可否判断コマンド完了待ち
 *
 *   ACT化可否判断コマンドが完了するまで待機する。
 *
 *   詳細は以下のとおり。
 *     -# ACT化可否判断コマンド実行中フラグが「真」の場合、状態変数を用いて、
 *        ACT化可否判断コマンド実行中フラグが「偽」に更新されるまで待機する。
 *
 * @version 1.1.0
 * @date    10/30/2007
 * @since   1.1
*/
#define WaitForCheckEnableToact() {\
	pthread_mutex_lock(&(g_WWCmnInfo.CheckEnableToactInfo.mutex));\
	while (g_WWCmnInfo.CheckEnableToactInfo.nFlag == TRUE) {\
		pthread_cond_wait(&(g_WWCmnInfo.CheckEnableToactInfo.cond), &(g_WWCmnInfo.CheckEnableToactInfo.mutex));\
	}\
	pthread_mutex_unlock(&(g_WWCmnInfo.CheckEnableToactInfo.mutex));\
}

/* 200807 -> */
/**
 * @def     NotifyTLIIsCompleted()
 * @brief   TLI通知完了情報を通知
 *
 *   TLI通知が完了したことを、他のスレッドに通知する。
 *
 *   詳細は以下のとおり。
 *     -# TLI通知完了情報のロック及び状態変数を用いて通知する。
 *
 * @note   マクロにて実装する。
 *
 * @version 1.3.0
 * @date    07/25/2008
 * @since   1.3
*/
#define NotifyTLIIsCompleted() { \
	g_WWCmnInfo.TLIInfo.nFlag = TRUE; \
	pthread_cond_signal (&(g_WWCmnInfo.TLIInfo.cond)); \
}
/* <- 200807 */

#endif  /* WWMESSAGETHREAD_H__ */
